@@ -1,17 +1,18 @@
+read_period_input <- function(){
+  utils::read.csv(system.file("extdata/shiny/period_input.csv", package = "sistec"),
+                  header = TRUE, colClasses = "character")
+}
+
 server_input_path <- function(input_path){
   slash <- stringr::str_locate_all(input_path[1], "/")
   last_slash <- slash[[1]][nrow(slash[[1]]), 2]
   substr(input_path[1], 1, last_slash)
 }
 
-shiny_comparison <- function(sistec_path, qacademico_path){
-  if(!is.null(sistec_path) && !is.null(qacademico_path)){
-    sistec_path <- server_input_path(sistec_path)
-    qacademico_path <- server_input_path(qacademico_path)
-    compare_sistec(sistec_path, qacademico_path)  
-  } else {
-    FALSE
-  }
+shiny_comparison <- function(sistec_path, rfept_path, year){
+  sistec <- read_sistec(server_input_path(sistec_path), year)
+  rfept <- read_rfept(server_input_path(rfept_path), year)
+  compare_sistec(sistec, rfept) 
 }
 
 shiny_output_path <- function(output_path){
@@ -24,6 +25,5 @@ shiny_output_path <- function(output_path){
       output_path <- tcltk::tk_choose.dir()
     }
   } 
-  
   output_path
-}
\ No newline at end of file
+}
